pub struct CreateSigningKeyParams {
pub create_signing_key_dto: CreateSigningKeyDto,
pub idempotency_key: Option<String>,
}Expand description
struct for passing parameters to the method
KeyLinkApi::create_signing_key
Fields
create_signing_key_dto: CreateSigningKeyDtoidempotency_key: Option<String>A unique identifier for the request. If the request is sent multiple times with the same idempotency key, the server will return the same response as the first request. The idempotency key is valid for 24 hours.
Implementations
Sourceimpl CreateSigningKeyParams
impl CreateSigningKeyParams
Sourcepub fn builder() -> CreateSigningKeyParamsBuilder
pub fn builder() -> CreateSigningKeyParamsBuilder
Create an instance of CreateSigningKeyParams using the builder syntax