pub struct DestinationTransferPeerPathResponse {
pub type: TransferPeerPathType,
pub sub_type: Option<String>,
pub id: Option<Option<String>>,
pub name: Option<String>,
pub wallet_id: Option<Uuid>,
pub trading_account: Option<Option<String>>,
}Expand description
DestinationTransferPeerPathResponse : Destination of the transaction.
Note: In case the transaction is sent to multiple destinations, the
destinations parameter is be used instead of this.
Fields
type: TransferPeerPathTypesub_type: Option<String>In case the type is set to EXCHANGE_ACCOUNT or FIAT_ACCOUNT, the
specific exchange vendor name or fiat vendor name.In case the type is
set to INTERNAL_WALLET or EXTERNAL_WALLET, the subType is set to
Internal or External.
id: Option<Option<String>>The ID of the peer. You can retrieve the ID of each venue object using the endpoints for listing vault accounts, listing exchange account, listing fiat accounts, listing internal wallets, listing external wallets, listing network connections. For the other types, this parameter is not needed.
name: Option<String>The name of the peer
wallet_id: Option<Uuid>trading_account: Option<Option<String>>If this transaction is an exchange internal transfer, this field will be populated with the type of that trading account.
Implementations
Sourceimpl DestinationTransferPeerPathResponse
impl DestinationTransferPeerPathResponse
Sourcepub fn new(type: TransferPeerPathType) -> DestinationTransferPeerPathResponse
pub fn new(type: TransferPeerPathType) -> DestinationTransferPeerPathResponse
Destination of the transaction. Note: In case the transaction is
sent to multiple destinations, the destinations parameter is be used
instead of this.