pub struct ExtraParameters {
pub node_controls: Option<NodeControls>,
pub raw_message_data: Option<ExtraParametersRawMessageData>,
pub contract_call_data: Option<String>,
pub program_call_data: Option<String>,
pub inputs_selection: Option<ExtraParametersInputsSelection>,
}Expand description
ExtraParameters : Additional protocol / operation specific key-value parameters: For UTXO-based blockchain input selection, add the key inputsSelection with the value set the input selection structure. The inputs can be retrieved from the Retrieve Unspent Inputs endpoint. For RAW operations, add the key rawMessageData with the value set to the raw message data structure. For CONTRACT_CALL operations, add the key contractCallData with the value set to the Ethereum smart contract Application Binary Interface (ABI) payload. The Fireblocks development libraries are recommended for building contract call transactions. *Note: rawMessageData, contractCallData, and inputsSelection cannot be used together in the same call."
Fields
node_controls: Option<NodeControls>raw_message_data: Option<ExtraParametersRawMessageData>contract_call_data: Option<String>Hex encoded contract call data as a string.
program_call_data: Option<String>inputs_selection: Option<ExtraParametersInputsSelection>Implementations
Sourceimpl ExtraParameters
impl ExtraParameters
Sourcepub fn new() -> ExtraParameters
pub fn new() -> ExtraParameters
Additional protocol / operation specific key-value parameters: For UTXO-based blockchain input selection, add the key inputsSelection with the value set the input selection structure. The inputs can be retrieved from the Retrieve Unspent Inputs endpoint. For RAW operations, add the key rawMessageData with the value set to the raw message data structure. For CONTRACT_CALL operations, add the key contractCallData with the value set to the Ethereum smart contract Application Binary Interface (ABI) payload. The Fireblocks development libraries are recommended for building contract call transactions. *Note: rawMessageData, contractCallData, and inputsSelection cannot be used together in the same call."