pub struct Tag {
pub id: Uuid,
pub label: String,
pub description: Option<String>,
pub color: Option<String>,
pub is_protected: bool,
pub updated_at: f64,
pub pending_approval_request: Option<ApprovalRequest>,
}Fields
id: UuidThe unique identifier of the tag
label: StringThe tag label
description: Option<String>Description for the tag
color: Option<String>The tag color in hex format
is_protected: boolIndication of whether the tag is a protected tag
updated_at: f64The date and time the tag was last updated
pending_approval_request: Option<ApprovalRequest>Implementations